BsDataColumn class

Inheritance

Constructors

BsDataColumn({Key? key, double? width, double height = 20.0, AlignmentGeometry? alignment, EdgeInsetsGeometry padding = const EdgeInsets.fromLTRB(12.0, 15.0, 12.0, 15.0), TextStyle? textStyle, BoxBorder? border, bool orderable = true, bool searchable = true, String searchValue = '', String searchRegex = 'false', String? columnName, String? columnData, BsOrderColumn orderState = const BsOrderColumn(), required Widget label})

Properties

alignment → AlignmentGeometry?
final
border → BoxBorder?
final
columnData → String?
final
columnName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget
final
orderable → bool
final
orderState ↔ BsOrderColumn
getter/setter pair
padding → EdgeInsetsGeometry
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchable → bool
final
searchRegex → String
final
searchValue → String
final
textStyle → TextStyle?
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderIcon(BuildContext context) → Widget
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited