BsDatatable class

Widget class to create datatable configuration

Inheritance

Constructors

BsDatatable({Key? key, required BsDatatableSource source, required List<BsDataColumn> columns, BsDatatableServerSide? serverSide, BsDatatableBuilder? customizeLayout, double? width, TextStyle? hintStyleSearch, Widget? title, TextStyle? titleTextStyle, List<BsPaginationButtons> pagination = BsPagination.buttons, Widget? notFoundText, Widget? processingText, Widget? textInfo, TextStyle? textInfoStyle, BsDatatableStyle style = const BsDatatableStyle(), BsPaginationButtonStyle stylePagination = const BsPaginationButtonStyle(), BsDatatableLanguage language = const BsDatatableLanguage(), BsDatatableOnRowPressed? onRowPressed, BsDatatablesClearData clearData = BsDatatablesClearData.always})
const

Properties

clearData → BsDatatablesClearData
final
columns → List<BsDataColumn>
Set columns of BsDatatable
final
customizeLayout → BsDatatableBuilder?
If you want to craete customize layout datatable, you can use BsDatatableBuilder class
final
hashCode → int
The hash code for this object.
no setterinherited
hintStyleSearch → TextStyle?
Set hintStyleSearch of BsDatatable
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
language → BsDatatableLanguage
Set language of BsDatatable
final
notFoundText → Widget?
Set not found text of BsDatatable
final
onRowPressed → BsDatatableOnRowPressed?
final
pagination → List<BsPaginationButtons>
Pagination configuration for datatable if you want to hide firstPage and lastPage you can set pagination without firstPage and lastPage
final
processingText → Widget?
Set processing text of BsDatatable
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverSide → BsDatatableServerSide?
Set serverSide of BsDatatable this properties must returned Future class serverSide properties is properties to get data from api server
final
source → BsDatatableSource
Set source of BsDatatable
final
style → BsDatatableStyle
Set style of BsDatatable
final
stylePagination → BsPaginationButtonStyle
Set style of pagination button BsDattable
final
textInfo → Widget?
Set textInfo of BsDatatable
final
textInfoStyle → TextStyle?
Set textInfostyle of BsDatatable
final
title → Widget?
Set title of BsDatatable
final
titleTextStyle → TextStyle?
Set title text style of BsDatatable
final
width → double?
Set width of BsDatatable
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited