BsDatatableController class

Constructors

BsDatatableController({int draw = 1, int start = 0, int length = 10, String searchValue = '', String searchRegex = 'false', List<Map<String, String>> orders = const [], List<Map<String, String>> columns = const []})

Properties

columns ↔ List<Map<String, String>>
getter/setter pair
draw ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ int
getter/setter pair
orders ↔ List<Map<String, String>>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchRegex ↔ String
getter/setter pair
searchValue ↔ String
getter/setter pair
start ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReloadListener(dynamic function(bool clearData)) → void
Set reload listener function
reload({bool clearData = true}) → void
Reloading data with create serverSide reqeust
toJson() → Map<String, String>
Before processing serverSide requests, datatable configuration must be converted to json
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited