BsDatatableLanguage class

Constructors

BsDatatableLanguage({String? perPageLabel = 'Perpage', String? searchLabel = 'Search', String hintTextSearch = 'Search ...', String firstPagination = 'First Page', String lastPagination = 'Last Page', String previousPagination = 'Previous', String nextPagination = 'Next', String information = 'Show __START__ to __END__ of __FILTERED__ entries', String informationFiltered = 'filtered from __DATA__ total enteries'})
const

Properties

firstPagination → String
final
hashCode → int
The hash code for this object.
no setterinherited
hintTextSearch → String
final
information → String
To customize information data message, you can use this word the system will replaced with avaible data
final
informationFiltered → String
To customize information on search data message, you can use this word the system will replaced with avaible data
final
lastPagination → String
final
nextPagination → String
final
perPageLabel → String?
final
previousPagination → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchLabel → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited