BsDatatableResponse class

Handle jquery datatable.net response format

Constructors

BsDatatableResponse({int draw = 0, int countData = 0, int countFiltered = 0, List<Map<String, dynamic>> data = const []})
BsDatatableResponse.createFromJson(Map<String, dynamic> map)
factory

Properties

countData → int
final
countFiltered → int
final
data ↔ List<Map<String, dynamic>>
getter/setter pair
draw → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited