BsDatatableSource class abstract

Constructors

BsDatatableSource({List<Map<String, dynamic>>? data, BsDatatableResponse? response, BsDatatableController? controller})

Properties

controller ↔ BsDatatableController
getter/setter pair
countData → int
Get count data from response
no setter
countDataPage → int
Get count data in page using response.data length
no setter
countFiltered → int
Get count filtered data from response
no setter
hashCode → int
The hash code for this object.
no setterinherited
response ↔ BsDatatableResponse
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Map<String, dynamic> value) → void
addAll(List<Map<String, dynamic>> values) → void
clear() → void
get(int index) → dynamic
getRow(int index) → BsDataRow
Set row widgets
insert(int index, Map<String, dynamic> element) → void
insertAll(int index, List<Map<String, dynamic>> iterable) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(int index, Map<String, dynamic> value) → void
reload({bool clear = false, List<Map<String, dynamic>> data = const []}) → void
remove(Map<String, dynamic> value) → void
removeAt(int index) → void
toString() → String
A string representation of this object.
inherited
update(List<Map<String, dynamic>>? values) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited