BsPaginationButtonStyle class

Constructors

BsPaginationButtonStyle({TextStyle textStyle = const TextStyle(), TextStyle textStyleActive = const TextStyle(color: Colors.white), Size minimumSize = const Size(20.0, 20.0), EdgeInsets padding = const EdgeInsets.only(left: 8.0, right: 8.0, top: 6.0, bottom: 6.0), BoxDecoration decoration = const BoxDecoration(), BoxDecoration activeDecoration = const BoxDecoration(color: Colors.blueAccent, borderRadius: BorderRadius.all(Radius.circular(50.0))), BorderRadius borderRadius = const BorderRadius.all(Radius.circular(50.0))})
const

Properties

activeDecoration → BoxDecoration
final
borderRadius → BorderRadius
final
decoration → BoxDecoration
final
hashCode → int
The hash code for this object.
no setterinherited
minimumSize → Size
final
padding → EdgeInsets
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle
final
textStyleActive → TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited